@@ -4,11 +4,11 @@ use 5.10.0;
 use namespace::autoclean;
 
 use Bubblegum::Role 'with';
-use Bubblegum::Constraints 'type_coderef';
+use Bubblegum::Constraints -isas, -types;
 
 with 'Bubblegum::Object::Role::Defined';
 
-our $VERSION = '0.34'; # VERSION
+our $VERSION = '0.35'; # VERSION
 
 sub do {
     my $self = CORE::shift;
